@@ -768,13 +768,13 @@ read_config(void)
 		}
 #endif
 
-	_GK.homedir = (gchar *) g_get_home_dir();
-	if (_GK.homedir == NULL)
-		_GK.homedir = ".";  // FIXME: doesn't look right to me
-
-	path = g_build_filename(_GK.homedir, GKRELLMD_USER_CONFIG, NULL);
-	load_config(path);
-	g_free(path);
+	const char *homedir = g_get_home_dir();
+	if (homedir)
+		{
+		path = g_build_filename(homedir, GKRELLMD_USER_CONFIG, NULL);
+		load_config(path);
+		g_free(path);
+		}
 	}
 
 static void
@@ -1614,23 +1614,21 @@ int main(int argc, char* argv[])
 	char *opt;
 
 #ifdef ENABLE_NLS
-#ifdef LOCALEDIR
 #if defined(WIN32)
-	gchar *install_path;
+	gchar *install_dir;
 	gchar *locale_dir;
 	// Prepend app install path to locale dir
-	install_path = g_win32_get_package_installation_directory_of_module(NULL);
-	if (install_path != NULL)
+	install_dir = g_win32_get_package_installation_directory_of_module(NULL);
+	if (install_dir != NULL)
 		{
-	    locale_dir = g_build_filename(install_path, LOCALEDIR, NULL);
+		locale_dir = g_build_filename(install_dir, "share", "locale", NULL);
 		bindtextdomain(PACKAGE_D, locale_dir);
 		g_free(locale_dir);
-	    g_free(install_path);
+		g_free(install_dir);
 		}
 #else
 	bindtextdomain(PACKAGE_D, LOCALEDIR);
 #endif /* !WIN32 */
-#endif /* LOCALEDIR */
 	textdomain(PACKAGE_D);
 	bind_textdomain_codeset(PACKAGE_D, "UTF-8");
 #endif	/* ENABLE_NLS */
