@@ -1614,27 +1614,7 @@ static GdkPixbuf	*alert_pixbuf;
 GdkPixbuf *
 gkrellm_alert_pixbuf(void)
 	{
-	guint8		*data = (guint8 *) alert_inline;
-	guint		width, height, stride;
-	gpointer	pixels;
-
 	if (!alert_pixbuf)
-		{
-//		alert_pixbuf = gdk_pixbuf_new_from_inline(-1, alert_inline,
-//						FALSE, NULL);
-		stride = big_endian_uint(data + 12);
-		width  = big_endian_uint(data + 16);
-		height = big_endian_uint(data + 20);
-
-#if GLIB_CHECK_VERSION(2, 68, 0)
-		pixels = g_memdup2((gconstpointer)(data + 24), height * stride);
-#else
-		pixels = g_memdup((gconstpointer)(data + 24), height * stride);
-#endif
-
-		alert_pixbuf = gdk_pixbuf_new_from_data(pixels,
-				GDK_COLORSPACE_RGB, TRUE, 8, width, height, stride,
-				(GdkPixbufDestroyNotify) g_free, pixels);
-		}
+		alert_pixbuf = gk_gdk_pixbuf_new_from_data(alert_inline);
 	return alert_pixbuf;
 	}
