@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Author:  Bill Wilson
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -57,23 +57,19 @@ static void	set_grid_resolution_spin_button(GkrellmChart *, gint);
 
 static GList	*chart_list;
 
-// #define DEBUG1
-// #define DEBUG2
-// #define DEBUG3
-
 /* ----------------------------------------------------------------------- */
 
 static gint
 computed_index(GkrellmChart *cp, gint i)
 	{
 	gint	x;
-	
+
 	x = (cp->position + i + 1) % cp->w;
 	return x;
 	}
 
 GList *
-gkrellm_get_chart_list()
+gkrellm_get_chart_list(void)
 	{
 	return chart_list;
 	}
@@ -114,8 +110,8 @@ gkrellm_clear_chart(GkrellmChart *cp)
 						0, 0,	0, 0,   cp->w, cp->h);
 	gdk_draw_drawable(cp->bg_pixmap, _GK.draw1_GC, cp->bg_src_pixmap,
 						0, 0,	0, 0,   cp->w, cp->h);
-	if (cp->drawing_area->window)
-		gdk_draw_drawable(cp->drawing_area->window, _GK.draw1_GC, cp->pixmap,
+	if (gtk_widget_get_window(cp->drawing_area))
+		gdk_draw_drawable(gtk_widget_get_window(cp->drawing_area), _GK.draw1_GC, cp->pixmap,
 						0, 0,	0, 0,   cp->w, cp->h);
 	}
 
@@ -158,8 +154,8 @@ gkrellm_draw_chart_to_screen(GkrellmChart *cp)
 	{
 	/* Draw the expose pixmap onto the screen.
 	*/
-	if (cp && cp->drawing_area->window)
-		gdk_draw_drawable(cp->drawing_area->window, _GK.draw1_GC, cp->pixmap,
+	if (cp && gtk_widget_get_window(cp->drawing_area))
+		gdk_draw_drawable(gtk_widget_get_window(cp->drawing_area), _GK.draw1_GC, cp->pixmap,
 						0, 0,	0, 0,   cp->w, cp->h);
 	}
 
@@ -282,7 +278,7 @@ chartdata_ycoord(GkrellmChart *cp, GkrellmChartdata *cd, gint yd)
 	{
 	glong	y;
 	guint64	Y;
-	
+
 	if (cp->scale_max <= 0)
 		cp->scale_max = 1;
 
@@ -685,11 +681,10 @@ gkrellm_alloc_chartdata(GkrellmChart *cp)
 	{
 	GList			*list;
 	GkrellmChartdata *cd;
-	size_t			w;
 
 	if (!cp)
 		return;
-	w = (size_t) cp->w;
+	int w = cp->w;
 	for (list = cp->cd_list; list; list = list->next)
 		{
 		cd = (GkrellmChartdata *) list->data;
@@ -860,7 +855,7 @@ gkrellm_store_chartdatav(GkrellmChart *cp, gulong total, va_list args)
 		cp->previous_total = total;	  /* Wrap around, this store won't scale */
 	total_diff = total - cp->previous_total;
 	cp->previous_total = total;
-		
+
 	/* Increment position in circular buffer and remember the data
 	|  value to be thrown out.
 	*/
@@ -1013,7 +1008,7 @@ gkrellm_draw_chart_text(GkrellmChart *cp, gint style_id, gchar *str)
 	GkrellmTextRun	*tr;
 	GkrellmTextstyle *ts, *ts_default, *ts_alt;
 	gchar			c, *s, *t;
-	gint			h, text_length, field_width, fw;
+	gint			h, field_width, fw;
 	gint			offset;
 	gint			xx, x, y, center, shadow;
 	gboolean		right, set_fw, fw_right;
@@ -1054,6 +1049,7 @@ gkrellm_draw_chart_text(GkrellmChart *cp, gint style_id, gchar *str)
 	y = 2 - cp->y_ink;
 	h = fw = 0;
 	tr = NULL;
+	size_t text_length = 0;
 	for (list = cp->text_run_list, s = str; *s; s += text_length)
 		{
 		if (!list)
@@ -1185,7 +1181,7 @@ gkrellm_draw_chart_text(GkrellmChart *cp, gint style_id, gchar *str)
 				buf[text_length] = '\0';
 				g_debug("draw_chart_text: [%s] ", buf);
 				}
-			
+
 			offset = cp->baseline_ref - tr->baseline;	/* align baselines */
 			if (_GK.chart_text_no_fill)
 	    		gkrellm_draw_text(cp->pixmap, ts, x, y + offset, s,
@@ -1239,7 +1235,7 @@ gkrellm_draw_chart_label(GkrellmChart *cp, GkrellmTextstyle *ts,
 	return x + w + ts->effect;
 	}
 
-void
+static void
 gkrellm_destroy_chartdata_list(GList **cd_list_head)
 	{
 	GList			*list;
@@ -1480,8 +1476,8 @@ gkrellm_add_chartdata(GkrellmChart *cp, GdkPixmap **src_pixmap,
 	cd->chart = cp;
 	gkrellm_dup_string(&cd->label, label);
 	cd->monotonic = TRUE;
-	cd->data_bitmap = gdk_pixmap_new(top_win->window, cp->w, cp->h, 1);
-	cd->layer.pixmap = gdk_pixmap_new(top_win->window, cp->w, cp->h, -1);
+	cd->data_bitmap = gdk_pixmap_new(gtk_widget_get_window(top_win), cp->w, cp->h, 1);
+	cd->layer.pixmap = gdk_pixmap_new(gtk_widget_get_window(top_win), cp->w, cp->h, -1);
 	cd->layer.src_pixmap = src_pixmap;
 	cd->layer.grid_pixmap = grid_pixmap;
 
@@ -1510,7 +1506,7 @@ gkrellm_render_data_grid_pixmap(GkrellmPiximage *im, GdkPixmap **pixmap,
 		else
 			{
 			gkrellm_free_pixmap(pixmap);
-			*pixmap = gdk_pixmap_new(top_win->window, w, 1, -1);
+			*pixmap = gdk_pixmap_new(gtk_widget_get_window(top_win), w, 1, -1);
 			if (color)
 				gdk_gc_set_foreground(_GK.draw1_GC, color);
 			else
@@ -1535,7 +1531,7 @@ gkrellm_render_data_pixmap(GkrellmPiximage *im, GdkPixmap **pixmap,
 		{
 		if (!gkrellm_scale_piximage_to_pixmap(im, pixmap, NULL, w, h))
 			{
-			*pixmap = gdk_pixmap_new(top_win->window, w, h, -1);
+			*pixmap = gdk_pixmap_new(gtk_widget_get_window(top_win), w, h, -1);
 			if (color)
 				gdk_gc_set_foreground(_GK.draw1_GC, color);
 			else
@@ -1754,22 +1750,11 @@ render_chart_margin_spacers(GkrellmChart *cp)
 		gtk_widget_hide(bs->vbox);
 	}
 
-#if 0
-static gboolean
-cb_chart_map_event(GtkWidget *widget, GdkEvent *event, GkrellmChart *cp)
-    {
-    gdk_window_get_position(cp->drawing_area->window, NULL, &cp->y_mapped);
-	if (_GK.frame_left_chart_overlap > 0 || _GK.frame_right_chart_overlap > 0)
-		_GK.need_frame_packing = TRUE;
-    return FALSE;
-    }
-#endif
-
 static gboolean
 cb_chart_size_allocate(GtkWidget *widget, GtkAllocation *size,
 				GkrellmChart *cp)
     {
-    gdk_window_get_position(cp->drawing_area->window, NULL, &cp->y_mapped);
+    gdk_window_get_position(gtk_widget_get_window(cp->drawing_area), NULL, &cp->y_mapped);
 	if (_GK.frame_left_chart_overlap > 0 || _GK.frame_right_chart_overlap > 0)
 		_GK.need_frame_packing = TRUE;
     return FALSE;
@@ -1856,7 +1841,7 @@ gkrellm_chart_create(GtkWidget *vbox, GkrellmMonitor *mon, GkrellmChart *cp,
 	cp->config->chart_cd_list = &cp->cd_list;
 
 	if (!cp->box)
-		{		
+		{
 		cp->box = gtk_vbox_new(FALSE, 0);	/* not a hbox anymore !! */
 		gtk_box_pack_start(GTK_BOX(vbox), cp->box, FALSE, FALSE, 0);
 
@@ -1882,9 +1867,7 @@ gkrellm_chart_create(GtkWidget *vbox, GkrellmMonitor *mon, GkrellmChart *cp,
 		cp->style_id = style_id;
 		insert_in_chartlist(cp);
 		cp->y_mapped = -1;
-//		g_signal_connect(G_OBJECT (cp->drawing_area), "map_event",
-//					G_CALLBACK(cb_chart_map_event), cp);
-		g_signal_connect(G_OBJECT (cp->drawing_area), "size_allocate",
+		g_signal_connect(G_OBJECT (cp->drawing_area), "size-allocate",
 					G_CALLBACK(cb_chart_size_allocate), cp);
 		}
 	else
@@ -2037,7 +2020,7 @@ set_grid_resolution_spin_button(GkrellmChart *cp, gint res)
 	if (!cp || !cp->config_window || !cp->config->grid_resolution_spin_button)
 		return;
 	spin = GTK_SPIN_BUTTON(cp->config->grid_resolution_spin_button);
-	gtk_spin_button_set_value(spin, (gfloat) res);	
+	gtk_spin_button_set_value(spin, (gfloat) res);
 	}
 
 static void
@@ -2107,7 +2090,7 @@ gkrellm_get_chartconfig_grid_resolution(GkrellmChartconfig *cf)
 
 void
 gkrellm_chartconfig_grid_resolution_connect(GkrellmChartconfig *cf,
-			void (*func)(gpointer), gpointer data)
+			void (*func)(GkrellmChartconfig *, gpointer), gpointer data)
 	{
 	if (!cf)
 		return;
@@ -2206,7 +2189,7 @@ gkrellm_get_chartconfig_fixed_grids(GkrellmChartconfig *cf)
 
 void
 gkrellm_chartconfig_fixed_grids_connect(GkrellmChartconfig *cf,
-			void (*func)(gpointer), gpointer data)
+			void (*func)(GkrellmChartconfig*, gpointer), gpointer data)
 	{
 	if (!cf)
 		return;
@@ -2224,7 +2207,7 @@ gkrellm_get_chartconfig_height(GkrellmChartconfig *cf)
 
 void
 gkrellm_chartconfig_height_connect(GkrellmChartconfig *cf,
-			void (*func)(gpointer), gpointer data)
+			void (*func)(GkrellmChartconfig*, gpointer), gpointer data)
 	{
 	if (!cf)
 		return;
@@ -2253,8 +2236,8 @@ gkrellm_set_chart_height(GkrellmChart *cp, gint h)
 		cd = (GkrellmChartdata *) list->data;
 		g_object_unref(G_OBJECT(cd->data_bitmap));
 		g_object_unref(G_OBJECT(cd->layer.pixmap));
-		cd->data_bitmap = gdk_pixmap_new(top_win->window, cp->w, cp->h, 1);
-		cd->layer.pixmap = gdk_pixmap_new(top_win->window, cp->w, cp->h, -1);
+		cd->data_bitmap = gdk_pixmap_new(gtk_widget_get_window(top_win), cp->w, cp->h, 1);
+		cd->layer.pixmap = gdk_pixmap_new(gtk_widget_get_window(top_win), cp->w, cp->h, -1);
 		}
 	cp->bg_sequence_id += 1;
 	render_chart_pixmaps(cp);
@@ -2321,7 +2304,7 @@ set_resolution_menubar_items_sensitivity(GkrellmChartconfig *cf)
 
 	w = gtk_ui_manager_get_widget(cf->auto_resolution_ui_manager,
                                       "/menubar/Control/AutoModeStickPeak");
-	GTK_CHECK_MENU_ITEM(w)->active = cf->auto_resolution_stick;
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(w), cf->auto_resolution_stick);
 
 	w = gtk_ui_manager_get_widget(cf->auto_resolution_ui_manager,
                                       "/menubar/Control/AutoModeRecalibrate");
@@ -2366,7 +2349,7 @@ static void
 cb_line_draw_style(GtkWidget *widget, GkrellmChartdata *cd)
 	{
 	_GK.config_modified = TRUE;
-	cd->draw_style = GTK_TOGGLE_BUTTON(widget)->active;
+	cd->draw_style = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 	gkrellm_rescale_chart(cd->chart);
 	}
 
@@ -2377,7 +2360,7 @@ cb_auto_resolution(GtkWidget *widget, GkrellmChart *cp)
 	GkrellmChartconfig	*cf = cp->config;
 
 	_GK.config_modified = TRUE;
-	cf->auto_grid_resolution = GTK_TOGGLE_BUTTON(widget)->active;
+	cf->auto_grid_resolution = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 
 	set_resolution_menubar_items_sensitivity(cf);
 	button = cf->grid_resolution_spin_button;
@@ -2392,7 +2375,7 @@ static void
 cb_inverted_draw_mode(GtkWidget *widget, GkrellmChartdata *cd)
 	{
 	_GK.config_modified = TRUE;
-	cd->inverted = GTK_TOGGLE_BUTTON(widget)->active;
+	cd->inverted = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 	gkrellm_rescale_chart(cd->chart);
 	}
 
@@ -2400,7 +2383,7 @@ static void
 cb_hide(GtkWidget *widget, GkrellmChartdata *cd)
 	{
 	_GK.config_modified = TRUE;
-	cd->hide = GTK_TOGGLE_BUTTON(widget)->active;
+	cd->hide = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 	set_chartdata_split_heights(cd->chart);
 	gkrellm_rescale_chart(cd->chart);
 	}
@@ -2409,7 +2392,7 @@ static void
 cb_split_mode(GtkWidget *widget, GkrellmChartdata *cd)
 	{
 	_GK.config_modified = TRUE;
-	cd->split_chart = GTK_TOGGLE_BUTTON(widget)->active;
+	cd->split_chart = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 	gtk_widget_set_sensitive(cd->split_fraction_spin_button, cd->split_chart);
 	set_chartdata_split_heights(cd->chart);
 	gkrellm_rescale_chart(cd->chart);
@@ -2479,7 +2462,7 @@ static const char *auto_res_control_items = "\
 </ui>\
 ";
 
-static GtkActionEntry auto_res_control_entries[] = 
+static GtkActionEntry auto_res_control_entries[] =
 {
     { "ControlAction", NULL, N_("Control"),
       NULL, NULL, G_CALLBACK(NULL) },
@@ -2490,14 +2473,14 @@ static GtkActionEntry auto_res_control_entries[] =
 };
 static guint n_auto_res_control_entries = G_N_ELEMENTS (auto_res_control_entries);
 
-static GtkToggleActionEntry auto_res_control_toggle_entries[] = 
+static GtkToggleActionEntry auto_res_control_toggle_entries[] =
 {
     { "AutoModeStickPeakAction", NULL, N_("Auto mode sticks at peak value"),
       NULL, NULL, G_CALLBACK(cb_auto_stick_control), FALSE },
 };
 static guint n_auto_res_control_toggle_entries = G_N_ELEMENTS (auto_res_control_toggle_entries);
 
-static GtkRadioActionEntry auto_res_control_radio_entries[] = 
+static GtkRadioActionEntry auto_res_control_radio_entries[] =
 {
     { "Seq125Action", NULL, N_("1 2 5"),
       NULL, NULL, 1 },
@@ -2560,7 +2543,7 @@ gkrellm_chartconfig_window_create(GkrellmChart *cp)
 		return;
 		}
 	cp->config_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	g_signal_connect(G_OBJECT(cp->config_window), "delete_event",
+	g_signal_connect(G_OBJECT(cp->config_window), "delete-event",
 			G_CALLBACK(chart_config_window_delete_event), cp);
 
 	p = cp->panel;
@@ -2688,7 +2671,7 @@ gkrellm_chartconfig_window_create(GkrellmChart *cp)
 	gtk_box_pack_start(GTK_BOX(main_vbox), hbox, FALSE, FALSE, 0);
 
 	button = gtk_button_new_from_stock(GTK_STOCK_OK);
-	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(button, 1);
 	g_signal_connect(G_OBJECT(button), "clicked",
 			G_CALLBACK(chart_config_window_close), cp);
     gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 15);
@@ -2768,29 +2751,3 @@ gkrellm_load_chartconfig(GkrellmChartconfig **config, gchar *string,
 			break;
 		}
 	}
-
-void
-debug_dump_chart_list()
-	{
-	GList			*list, *cdlist;
-	GkrellmChart	*cp;
-	GkrellmPanel	*p;
-	GkrellmChartdata *cd;
-
-	g_debug("\n");
-	for (list = gkrellm_get_chart_list(); list; list = list->next)
-		{
-		cp = (GkrellmChart *) list->data;
-		p = cp->panel;
-		if (p && p->label && p->label->string)
-			g_debug("%s [%d]: ", p->label->string, cp->style_id);
-		else
-			g_debug("(null) [%d]: ", cp->style_id);
-		for (cdlist = cp->cd_list; cdlist; cdlist = cdlist->next)
-			{
-			cd = (GkrellmChartdata *) cdlist->data;
-			g_debug("%s %p->data ", cd->label, cd->data);
-			}
-		g_debug("\n");
-		}
-	}
