@@ -111,13 +111,20 @@ G_BEGIN_DECLS
 
 #if !defined(WIN32)
 
-#define	LOCAL_THEMES_DIR		"/usr/local/share/gkrellm2/themes"
-#if !defined(SYSTEM_THEMES_DIR)
-#define	SYSTEM_THEMES_DIR		"/usr/share/gkrellm2/themes"
+#if !defined(LOCAL_THEMES_DIR)
+#define LOCAL_THEMES_DIR "/usr/local/share/gkrellm2/themes"
 #endif
-#define	LOCAL_PLUGINS_DIR		"/usr/local/lib/gkrellm2/plugins"
+
+#if !defined(SYSTEM_THEMES_DIR)
+#define SYSTEM_THEMES_DIR "/usr/share/gkrellm2/themes"
+#endif
+
+#if !defined(LOCAL_PLUGINS_DIR)
+#define LOCAL_PLUGINS_DIR "/usr/local/lib/gkrellm2/plugins"
+#endif
+
 #if !defined(SYSTEM_PLUGINS_DIR)
-#define	SYSTEM_PLUGINS_DIR		"/usr/lib/gkrellm2/plugins"
+#define SYSTEM_PLUGINS_DIR "/usr/lib/gkrellm2/plugins"
 #endif
 
 #else
