@@ -1685,6 +1685,7 @@ cb_load_theme(GtkAction *action, GtkWidget *widget)
 			gtk_tree_model_iter_nth_child(theme_model, &iter, NULL, row);
 			path = gtk_tree_model_get_path(theme_model, &iter);
 			gtk_tree_view_set_cursor(theme_treeview, path, NULL, FALSE);
+			gtk_tree_path_free(path);
 			return;		/* cb_theme_tree_selection_changed -> gkrellm_build()*/
 			}
 		theme = (Theme *) theme_position_in_list->data;
@@ -2069,9 +2070,9 @@ gkrellm_add_plugin_config_page(GkrellmMonitor *mon)
 					create_config_page(mon, model, &iter, config_notebook);
 		mon->privat->config_created = FALSE;
 
-		mon->privat->row_reference =
-			gtk_tree_row_reference_new(GTK_TREE_MODEL(model),
-					gtk_tree_model_get_path(GTK_TREE_MODEL(model), &iter));
+		path = gtk_tree_model_get_path(GTK_TREE_MODEL(model), &iter);
+		mon->privat->row_reference = gtk_tree_row_reference_new(GTK_TREE_MODEL(model), path);
+		gtk_tree_path_free(path);
 		}
 	else
 		mon->privat->config_page = -1;
@@ -2261,9 +2262,10 @@ create_config_window(void)
 		mon->privat->config_vbox =
 					create_config_page(mon, model, &citer, config_notebook);
 		mon->privat->config_created = FALSE;
-		mon->privat->row_reference =
-			gtk_tree_row_reference_new(GTK_TREE_MODEL(model),
-					gtk_tree_model_get_path(GTK_TREE_MODEL(model), &citer));
+
+		path = gtk_tree_model_get_path(GTK_TREE_MODEL(model), &citer);
+		mon->privat->row_reference = gtk_tree_row_reference_new(GTK_TREE_MODEL(model), path);
+		gtk_tree_path_free(path);
 		}
 
 	gtk_tree_store_append(model, &iter, NULL);
@@ -2405,7 +2407,7 @@ gk_show_about_dialog()
 
 	static const gchar *copyright =
 		"Copyright \302\251 1999-2021 Bill Wilson\n"
-		"Copyright \302\251 2024 Stefan Gehn\n";
+		"Copyright \302\251 2024-2026 Stefan Gehn\n";
 
 	static const gchar *license =
 		"This program is free software: you can redistribute it and/or modify "
