@@ -1996,26 +1996,21 @@ main(gint argc, gchar **argv)
 	gtk_widget_push_colormap(gdk_rgb_get_colormap());
 
 #ifdef ENABLE_NLS
-#ifdef LOCALEDIR
 #if defined(WIN32)
-	gchar *install_path;
+	gchar *install_dir;
 	gchar *locale_dir;
 	// Prepend app install path to locale dir
-	install_path = g_win32_get_package_installation_directory_of_module(NULL);
-	if (install_path != NULL)
+	install_dir = g_win32_get_package_installation_directory_of_module(NULL);
+	if (install_dir != NULL)
 		{
-	    locale_dir = g_build_filename(install_path, LOCALEDIR, NULL);
-		if (locale_dir != NULL)
-			{
-			bindtextdomain(PACKAGE, locale_dir);
-			g_free(locale_dir);
-			}
-	    g_free(install_path);
+		locale_dir = g_build_filename(install_dir, "share", "locale", NULL);
+		bindtextdomain(PACKAGE, locale_dir);
+		g_free(locale_dir);
+		g_free(install_dir);
 		}
 #else
 	bindtextdomain(PACKAGE, LOCALEDIR);
 #endif /* !WIN32 */
-#endif /* LOCALEDIR */
 	textdomain(PACKAGE);
 	bind_textdomain_codeset(PACKAGE, "UTF-8");
 #endif	/* ENABLE_NLS */
