@@ -169,8 +169,6 @@ gkrellm_panel_configure(GkrellmPanel *p, gchar *string, GkrellmStyle *style)
 		lbl->height = ink.height;
 		if (ts->effect)
 			lbl->height += 1;
-//		gkrellm_text_extents(ts->font, string, strlen(string),
-//				&lbl->width, &lbl->height, &baseline, NULL);
 		}
 	else
 		{
@@ -271,15 +269,6 @@ draw_panel_label(GkrellmPanel *p, gboolean to_bg)
 		if (to_bg)
 			gdk_draw_layout(p->bg_pixmap, _GK.text_GC, xdst,
 							lbl->y_panel, p->label_layout);
-#if 0
-		lbl->width = gkrellm_gdk_string_width(ts->font, s) + ts->effect;
-		xdst = gkrellm_label_x_position(lbl->position, p->w,
-					lbl->width, m->left);
-		lbl->x_panel = xdst;
-		gkrellm_draw_string(p->pixmap, ts, xdst, lbl->y_panel, s);
-		if (to_bg)
-			gkrellm_draw_string(p->bg_pixmap, ts, xdst, lbl->y_panel, s);
-#endif
 		}
 	}
 
@@ -469,8 +458,6 @@ gkrellm_panel_create(GtkWidget *vbox, GkrellmMonitor *mon, GkrellmPanel *p)
 		gkrellm_border_adjust(&piximage.border,
 				-_GK.frame_left_panel_overlap, -_GK.frame_right_panel_overlap,
 				0, 0);
-//		gkrellm_scale_piximage_to_pixmap(&piximage, &p->bg_clean_pixmap,
-//				&p->bg_mask, p->w, p->h);
 		gkrellm_scale_theme_background(&piximage, &p->bg_clean_pixmap,
 				&p->bg_mask, p->w, p->h);
 		g_object_unref(G_OBJECT(piximage.pixbuf));
@@ -478,8 +465,6 @@ gkrellm_panel_create(GtkWidget *vbox, GkrellmMonitor *mon, GkrellmPanel *p)
 	else
 		gkrellm_scale_theme_background(p->bg_piximage, &p->bg_clean_pixmap,
 			&p->bg_mask, p->w, p->h);
-//		gkrellm_scale_piximage_to_pixmap(p->bg_piximage, &p->bg_clean_pixmap,
-//			&p->bg_mask, p->w, p->h);
 
 	if (p->bg_text_layer_pixmap)
 		g_object_unref(G_OBJECT(p->bg_text_layer_pixmap));
