@@ -639,63 +639,61 @@ gkrellm_clone_piximage(GkrellmPiximage *src_piximage)
 	return piximage;
 	}
 
+// TODO: make public API?
+static GkrellmPiximage *
+piximage_new_from_pixbuf(GdkPixbuf *pixbuf)
+	{
+	if (!pixbuf)
+		return NULL;
+	GkrellmPiximage *piximage = g_new0(GkrellmPiximage, 1);
+	piximage->pixbuf = pixbuf;
+	return piximage;
+	}
+
 GkrellmPiximage *
 gkrellm_piximage_new_from_xpm_data(gchar **data)
 	{
-	GkrellmPiximage	*piximage;
-	GdkPixbuf		*pixbuf;
-
-	pixbuf = gdk_pixbuf_new_from_xpm_data((const char **) data);
-	if (!pixbuf)
-		return NULL;
-	piximage = g_new0(GkrellmPiximage, 1);
-	piximage->pixbuf = pixbuf;
-	return piximage;
+	return piximage_new_from_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **) data));
 	}
 
 GkrellmPiximage *
 gkrellm_piximage_new_from_file(gchar *fname)
 	{
-	GkrellmPiximage	*piximage;
-	GdkPixbuf		*pixbuf;
+	return piximage_new_from_pixbuf(gdk_pixbuf_new_from_file(fname, NULL));
+	}
 
-	pixbuf = gdk_pixbuf_new_from_file(fname, NULL);
-	if (!pixbuf)
-		return NULL;
-	piximage = g_new0(GkrellmPiximage, 1);
-	piximage->pixbuf = pixbuf;
-	return piximage;
+static guint
+big_endian_uint(const guint8 *b)
+	{
+	return ((b[0] << 24) | (b[1] << 16) | (b[2] << 8) | b[3]);
+	}
+
+static void
+gk_gdk_pixbuf_free_data(guchar *pixels, G_GNUC_UNUSED gpointer data)
+{
+	g_free(pixels);
+}
+
+GdkPixbuf *
+gk_gdk_pixbuf_new_from_data(const guint8 *data)
+	{
+	const guint stride = big_endian_uint(data + 12);
+	const guint width  = big_endian_uint(data + 16);
+	const guint height = big_endian_uint(data + 20);
+
+#if GLIB_CHECK_VERSION(2, 68, 0)
+	gpointer pixels = g_memdup2(data + 24, height * stride);
+#else
+	gpointer pixels = g_memdup(data + 24, height * stride);
+#endif
+
+	return gdk_pixbuf_new_from_data(pixels,
+				GDK_COLORSPACE_RGB, TRUE, 8, width, height, stride,
+				gk_gdk_pixbuf_free_data, NULL);
 	}
 
 GkrellmPiximage *
 gkrellm_piximage_new_from_inline(const guint8 *data, gboolean copy_pixels)
 	{
-	GkrellmPiximage	*piximage;
-	GdkPixbuf		*pixbuf;
-	guint			width, height, stride;
-	guint8			*d = (guint8 *) data;
-	gpointer		pixels;
-
-
-//	pixbuf = gdk_pixbuf_new_from_inline(-1, data, copy_pixels, NULL);
-	stride = big_endian_uint(d + 12);
-	width  = big_endian_uint(d + 16);
-	height = big_endian_uint(d + 20);
-
-#if GLIB_CHECK_VERSION(2, 68, 0)
-	pixels = g_memdup2((gconstpointer)(d + 24), height * stride);
-#else
-	pixels = g_memdup((gconstpointer)(d + 24), height * stride);
-#endif
-
-	pixbuf = gdk_pixbuf_new_from_data(pixels,
-				GDK_COLORSPACE_RGB, TRUE, 8, width, height, stride,
-				(GdkPixbufDestroyNotify) g_free, pixels);
-
-
- 	if (!pixbuf)
-		return NULL;
-	piximage = g_new0(GkrellmPiximage, 1);
-	piximage->pixbuf = pixbuf;
-	return piximage;
+	return piximage_new_from_pixbuf(gk_gdk_pixbuf_new_from_data(data));
 	}
