@@ -882,6 +882,9 @@ install_plugin(gchar *plugin_name)
 
 	if (!g_module_supported())
 		return NULL;
+
+	gkrellm_debug(DEBUG_PLUGIN, "Loading plugin %s\n", plugin_name);
+
 	module = g_module_open(plugin_name, 0);
 	plugin_log(plugin_name, "\n", NULL);
 
@@ -1140,51 +1143,35 @@ save_plugins_enable_file(void)
 	g_free(path);
 	}
 
-static gchar *
-string_suffix(gchar *string, gchar *suffix)
-	{
-	gchar	*dot;
-
-	dot = strrchr(string, '.');
-	if (dot && !strcmp(dot + 1, suffix))
-		return dot + 1;
-	return NULL;
-	}
+#if defined(WIN32)
+static const char *plugin_suffix = ".dll";
+#else // macOS/Darwin also uses .so for historic reasons
+static const char *plugin_suffix = ".so";
+#endif
 
 static void
 scan_for_plugins(gchar *path)
 	{
-    GDir			*dir;
-    gchar			*name, *filename;
+	gchar			*name;
 	GList			*list;
 	GkrellmMonitor	*m = NULL;
 	gchar			*s;
 	gboolean		exists;
 
-	if (!path || !*path || (dir = g_dir_open(path, 0, NULL)) == NULL)
+	if (!path || !*path)
 		return;
+
+	gkrellm_debug(DEBUG_PLUGIN, "Searching for plugins in %s\n", path);
+
+	GDir *dir = g_dir_open(path, 0, NULL);
+	if (!dir)
+		return;
+
 	while ((name = (gchar *) g_dir_read_name(dir)) != NULL)
 		{
-		if (   !string_suffix(name, "so")
-			&& !string_suffix(name, "la")
-			&& !string_suffix(name, "dll")
-		   )
+		if (!g_str_has_suffix(name, plugin_suffix))
 			continue;
 
-		/* If there's a libtool .la archive, won't want to load this .so
-		*/
-		if (   !string_suffix(name, "la")
-			&& (s = strrchr(name, '.')) != NULL
-		   )
-			{
-			s = g_strndup(name, s - name);
-			filename = g_strconcat(path, G_DIR_SEPARATOR_S, s, ".la", NULL);
-			exists = g_file_test(filename, G_FILE_TEST_EXISTS);
-			g_free(s);
-			g_free(filename);
-			if (exists)
-				continue;
-			}
 		for (list = plugins_list; list; list = list->next)
 			{
 			m = (GkrellmMonitor *) list->data;
@@ -1579,7 +1566,6 @@ cb_place_button(GtkWidget *widget, gpointer data)
 		}
 	else
 		gtk_window_present(GTK_WINDOW(place_plugin_window));
-//		gdk_window_raise(place_plugin_window->window);
 
 	if (row_reference)
 		{
@@ -1637,6 +1623,7 @@ cb_tree_selection_changed(GtkTreeSelection *selection, gpointer data)
 		}
 	path = gtk_tree_model_get_path(model, &iter);
 	row_reference = gtk_tree_row_reference_new(model, path);
+	gtk_tree_path_free(path);
 	gtk_tree_model_get(model, &iter, MON_COLUMN, &mon, -1);
 	place_button_sensitivity(mon, mon->privat->enabled);
 	}
