@@ -355,6 +355,31 @@ gkrellm_sensors_create_decals(GkrellmPanel *p, gint style_id,
 	*dfan = df;
 	}
 
+
+static void
+sensors_draw_decal_float_with_unit(GkrellmPanel *panel, GkrellmDecal *decal, gfloat value, char unit_suffix)
+{
+	g_assert(panel);
+	g_assert(decal);
+
+	char buf[8];
+	snprintf(buf, sizeof(buf), "%.1f%c", value, unit_suffix);
+
+	int w = gkrellm_gdk_string_width(decal->text_style.font, buf) + decal->text_style.effect;
+	if (w > decal->w + 1)
+		{ // not enough width -> retry with less precision
+		snprintf(buf, sizeof(buf), "%.0f%c", value, unit_suffix);
+		w = gkrellm_gdk_string_width(decal->text_style.font, buf) + decal->text_style.effect;
+		}
+
+	decal->x_off = decal->w - w;
+	if (decal->x_off < 0)
+		decal->x_off = 0;
+
+	gkrellm_draw_decal_text(panel, decal, buf, -1);
+}
+
+
 void
 gkrellm_sensor_draw_fan_decal(GkrellmPanel *p, GkrellmDecal *d, gfloat f)
 	{
@@ -376,27 +401,9 @@ void
 gkrellm_sensor_draw_temperature_decal(GkrellmPanel *p, GkrellmDecal *d,
 				gfloat t, gchar units)
 	{
-	gchar	*s, buf[8];
-	gint	w;
-
 	if (!p || !d)
 		return;
-	snprintf(buf, sizeof(buf), "%.1f%c", t, units);
-	if ((s = strchr(buf, '.')) == NULL)
-		s = strchr(buf, ',');			/* Locale may use commas */
-	w = gkrellm_gdk_string_width(d->text_style.font, buf)
-				+ d->text_style.effect;
-	if (w > d->w + 1)
-		{
-		snprintf(buf, sizeof(buf), "%.0f%c", t, units);
-		w = gkrellm_gdk_string_width(d->text_style.font, buf)
-				+ d->text_style.effect;
-		}
-
-	d->x_off = d->w - w;
-	if (d->x_off < 0)
-		d->x_off = 0;
-	gkrellm_draw_decal_text(p, d, buf, 0 /* no longer used */);
+	sensors_draw_decal_float_with_unit(p, d, t, units);
 	}
 
 static Sensor *
@@ -1201,142 +1208,148 @@ name_text_fit(Sensor *s, GkrellmDecal *dn, GkrellmDecal *ds)
 	return string;
 	}
 
-
+/**
+ * Draw all temperature sensors in temperature panel
+ * If @p draw_name_decals is TRUE also render the name decal (only needed once)
+ */
 static void
-draw_temperatures(gboolean draw_name)
+draw_temperatures(gboolean draw_name_decals)
 	{
-	GList		*list;
-	SensorMon	*smon;
-	Sensor		*sensor;
-	gfloat		t;
-	gchar		*name, units;
-
 	if (!pTemp)
 		return;
-	for (list = temperature_list; list; list = list->next)
-		{
-		smon = (SensorMon *) list->data;
-		sensor = smon->sensor;
 
-		if (draw_name && smon->name_decal)
+	for (GList *list = temperature_list; list; list = list->next)
+		{
+		SensorMon *smon = (SensorMon *)list->data;
+		Sensor *sensor = smon->sensor;
+
+		if (draw_name_decals && smon->name_decal)
 			{
-			name = name_text_fit(sensor, smon->name_decal, smon->sensor_decal);
+			gchar *name = name_text_fit(sensor, smon->name_decal, smon->sensor_decal);
 			gkrellm_draw_decal_markup(pTemp, smon->name_decal, name);
 			g_free(name);
 			}
+
 		if (smon->sensor_decal)
 			{
+			gfloat t;
+			gchar units;
 			sensor_read_temperature(sensor, &t, &units);
-			gkrellm_sensor_draw_temperature_decal(pTemp, smon->sensor_decal,
-					t, units);
+			gkrellm_sensor_draw_temperature_decal(pTemp, smon->sensor_decal, t, units);
 			}
 		}
+
 	gkrellm_draw_panel_layers(pTemp);
 	}
 
+/**
+ * Draw all fan sensors in fan panel
+ * If @p draw_name_decals is TRUE also render the name decal (only needed once)
+ */
 static void
-draw_fans(gboolean draw_name)
+draw_fans(gboolean draw_name_decals)
 	{
-	GList		*list;
-	SensorMon	*smon;
-	Sensor		*sensor;
-	gchar		*name;
-	gfloat		f;
-
 	if (!pFan)
 		return;
-	for (list = fan_list; list; list = list->next)
-		{
-		smon = (SensorMon *) list->data;
-		sensor = smon->sensor;
 
-		if (draw_name && smon->name_decal)
+	for (GList *list = fan_list; list; list = list->next)
+		{
+		SensorMon *smon = (SensorMon *)list->data;
+		Sensor *sensor = smon->sensor;
+
+		if (draw_name_decals && smon->name_decal)
 			{
-			name = name_text_fit(sensor, smon->name_decal, smon->sensor_decal);
+			gchar *name = name_text_fit(sensor, smon->name_decal, smon->sensor_decal);
 			gkrellm_draw_decal_markup(pFan, smon->name_decal, name);
 			g_free(name);
 			}
+
 		if (smon->sensor_decal)
 			{
+			gfloat f;
 			sensor_read_fan(sensor, &f);
 			gkrellm_sensor_draw_fan_decal(pFan, smon->sensor_decal, f);
 			}
 		}
+
 	gkrellm_draw_panel_layers(pFan);
 	}
 
-  /* If s is NULL, draw 'em all
-  */
+/**
+ * Draw voltage sensors in voltage panel
+ * if @p is not NULL only that sensor will be redrawn, otherwise redraw all sensors
+ * If @p draw_name_decals is TRUE also render the name decal (only needed once)
+ */
 static void
-draw_voltages(Sensor *s, gint do_names)
+draw_voltages(Sensor *s, gboolean draw_name_decals)
 	{
-	GList			*list;
-	SensorMon		*volt;
-	Sensor			*sensor;
-	GkrellmDecal	*ds, *dn;
-	gchar			*name, *fmt, buf[32];
-	gfloat			v;
-
 	if (!pVolt)
 		return;
-	for (list = volt_list; list; list = list->next)
+
+	for (GList *list = volt_list; list; list = list->next)
 		{
-		volt = (SensorMon *) list->data;
-		sensor = volt->sensor;
+		SensorMon *volt = (SensorMon *) list->data;
+		Sensor *sensor = volt->sensor;
 		if (s && s != sensor)
 			continue;
 		sensor->value_valid = FALSE;	/* In case vref monitoring stops */
-		dn = volt->name_decal;
-		ds = volt->sensor_decal;
-		if (do_names && dn)
+
+		if (draw_name_decals && volt->name_decal)
 			{
-			name = name_text_fit(sensor, dn, ds);
-			gkrellm_draw_decal_markup(pVolt, dn, name);
+			gchar *name = name_text_fit(sensor, volt->name_decal, volt->sensor_decal);
+			gkrellm_draw_decal_markup(pVolt, volt->name_decal, name);
 			g_free(name);
 			}
-		if (ds)
+
+		if (volt->sensor_decal)
 			{
 			if (sensor->vref && !sensor->vref->value_valid)
 				sensor_read_voltage(sensor->vref, NULL);
+
+			gfloat v;
 			sensor_read_voltage(sensor, &v);
 			sensor->value_valid = TRUE;
+
+			char buf[32];
 			if ((v < 10.0 && v > 0.0) || (v > -10.0 && v < 0.0))
-				fmt = "%.2f";
+				snprintf(buf, sizeof(buf), "%.2f", v);
 			else
-				fmt = "%.1f";
-			snprintf(buf, sizeof(buf), fmt, v);
-			ds->x_off = (v < 0.0) ? 0 : minus_width;
-			gkrellm_draw_decal_text(pVolt, ds, buf, -1);
+				snprintf(buf, sizeof(buf), "%.1f", v);
+
+			volt->sensor_decal->x_off = (v < 0.0) ? 0 : minus_width;
+			gkrellm_draw_decal_text(pVolt, volt->sensor_decal, buf, -1);
 			}
 		}
 	gkrellm_draw_panel_layers(pVolt);
 	}
 
+/**
+ * Draw power sensors in power panel
+ * If @p draw_name_decals is TRUE also render the name decal (only needed once)
+ */
 static void
-draw_power_sensors(Sensor *sensor, gboolean force_draw)
+draw_power_sensors(gboolean draw_name_decal)
 	{
-	GList		*list;
-	SensorMon	*smon;
-	gchar		*name, buf[32];
-	gfloat		p;
-
 	if (!pPower)
 		return;
-	for (list = power_list; list; list = list->next)
+
+	for (GList *list = power_list; list; list = list->next)
 		{
-		smon = (SensorMon *) list->data;
-		sensor = smon->sensor;
-		if (smon->name_decal)
+		SensorMon *smon = (SensorMon *) list->data;
+		Sensor *sensor = smon->sensor;
+
+		if (draw_name_decal && smon->name_decal)
 			{
-			name = name_text_fit(sensor, smon->name_decal, smon->sensor_decal);
+			gchar *name = name_text_fit(sensor, smon->name_decal, smon->sensor_decal);
 			gkrellm_draw_decal_markup(pPower, smon->name_decal, name);
 			g_free(name);
 			}
+
 		if (smon->sensor_decal)
 			{
+			gfloat p;
 			sensor_read_power(sensor, &p);
-			snprintf(buf, sizeof(buf), "%.1fW", p);
-			gkrellm_draw_decal_text(pPower, smon->sensor_decal, buf, -1);
+			sensors_draw_decal_float_with_unit(pPower, smon->sensor_decal, p, 'W');
 			}
 		}
 	gkrellm_draw_panel_layers(pPower);
@@ -1362,7 +1375,7 @@ update_sensors(void)
 	draw_temperatures(FALSE);
 	draw_fans(FALSE);
 	draw_voltages(NULL, FALSE);
-	draw_power_sensors(NULL, FALSE);
+	draw_power_sensors(FALSE);
 	update_disk_temperatures();
 	first_time_done = TRUE;
 	}
@@ -1644,7 +1657,7 @@ make_power_panel(GtkWidget *vbox, gboolean first_create)
 		g_signal_connect(G_OBJECT(pPower->drawing_area), "button-press-event",
 				G_CALLBACK(cb_panel_press), pPower);
 		}
-	draw_power_sensors(NULL, TRUE);
+	draw_power_sensors(TRUE);
 	}
 
 static void
@@ -2260,6 +2273,7 @@ get_referenced_sensor(void)
 	gtk_tree_model_get_iter(model, &iter, path);
 	gtk_tree_model_get(model, &iter,
 			SENSOR_COLUMN, &s, -1);
+	gtk_tree_path_free(path);
 	return s;
 	}
 
@@ -2970,14 +2984,10 @@ create_sensors_tab(GtkWidget *tab_vbox)
 	gtk_container_add(GTK_CONTAINER(alert_button), box);
 	gtk_box_pack_end(GTK_BOX(vbox1), alert_button, FALSE, FALSE, 4);
 
-//	gkrellm_gtk_button_connected(vbox1, &alert_button, FALSE, FALSE, -5,
-//				cb_set_alert, NULL, "Alerts");
-
 	set_sensor_widget_states(NULL);
 
 /* -- Options tab */
 	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Options"));
-//	box = gkrellm_gtk_framed_vbox(vbox, _("Temperatures"), 4, FALSE, 0, 2);
 	box = gkrellm_gtk_category_vbox(vbox, _("Temperatures"), 4, 0, TRUE);
 	gkrellm_gtk_check_button_connected(box, &button,
 				units_fahrenheit, FALSE, FALSE, 0,
@@ -2990,7 +3000,6 @@ create_sensors_tab(GtkWidget *tab_vbox)
 	if (!sensor_list)
 		gtk_widget_set_sensitive(button, FALSE);
 
-//	box = gkrellm_gtk_framed_vbox(vbox, _("Voltages"), 6, FALSE, 0, 2);
 	box = gkrellm_gtk_category_vbox(vbox, _("Voltages"), 4, 0, TRUE);
 	button = gtk_radio_button_new_with_label(NULL,
 				_("Normal with labels"));
