@@ -1,7 +1,7 @@
 /* GKrellM
 |  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson
 |  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |  DragonFly code: Joerg Sonnenberger <joerg@bec.de>
@@ -17,7 +17,7 @@
 |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 |  GNU General Public License for more details.  Version 2 is in the
 |  COPYRIGHT file in the top level directory of this distribution.
-| 
+|
 |  To get a copy of the GNU General Puplic License, write to the Free Software
 |  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
@@ -28,8 +28,7 @@ kvm_t	*kvmd = NULL;
 char	errbuf[_POSIX2_LINE_MAX];
 
 
-// extern gboolean force_meminfo_update(void);
-#if defined(__i386__)
+#if defined(__i386__) || defined(__x86_64__)
 static void scan_for_sensors();
 #endif
 
@@ -46,7 +45,7 @@ gkrellm_sys_main_init(void)
 		fprintf(stderr, "Can't drop setgid privileges.");
 		exit(1);
 		}
-#if defined(__i386__)
+#if defined(__i386__) || defined(__x86_64__)
 	scan_for_sensors();
 #endif
 	if (setuid(getuid()) != 0)
@@ -90,7 +89,7 @@ get_ncpus(void)
 {
 	static int mib[] = { CTL_HW, HW_NCPU };
 	int ncpus;
-	int len = sizeof(int);
+	size_t len = sizeof(int);
 
 	if (sysctl(mib, 2, &ncpus, &len, NULL, 0) < 0)
 		return 1;
@@ -101,20 +100,21 @@ get_ncpus(void)
 void
 gkrellm_sys_cpu_read_data(void)
 {
-  int len, n;
+	size_t len;
+	int n;
 
-  if (!cp_time)
-    return;
+	if (!cp_time)
+		return;
 
-  len = sizeof (*cp_time) * ncpus;
-  if (sysctlbyname("kern.cputime", cp_time, &len, NULL, 0) != 0)
-    return;
+	len = sizeof (*cp_time) * ncpus;
+	if (sysctlbyname("kern.cputime", cp_time, &len, NULL, 0) != 0)
+		return;
 
-  for (n = 0; n < ncpus; n++)
-    gkrellm_cpu_assign_data(n, cp_time[n].cp_user,
-			    cp_time[n].cp_nice,
-			    cp_time[n].cp_sys,
-			    cp_time[n].cp_idle);
+	for (n = 0; n < ncpus; n++)
+		gkrellm_cpu_assign_data(n, cp_time[n].cp_user,
+					cp_time[n].cp_nice,
+					cp_time[n].cp_sys,
+					cp_time[n].cp_idle);
 }
 
 gboolean
@@ -133,16 +133,10 @@ gkrellm_sys_cpu_init(void)
 #include <sys/sysctl.h>
 #include <sys/user.h>
 
-/*
- * This is ugly, but we need PID_MAX, in anyway.  Since 5.0-RELEASE
- * will have vm.stats.vm.v_forks, this will be obsolete in the future.
- */
-#define	PID_MAX		99999
-
 #include <kvm.h>
 #include <limits.h>
 #include <paths.h>
-#include <utmp.h>
+#include <utmpx.h>
 
 extern	kvm_t	*kvmd;
 
@@ -211,12 +205,20 @@ gkrellm_sys_proc_read_users(void)
 	gint		n_users;
 	struct stat	sb, s;
 	gchar		ttybuf[MAXPATHLEN];
+#ifdef _PATH_UTMP
 	FILE		*ut;
 	struct utmp	utmp;
+#define UTMP_FILE	_PATH_UTMP
+#else
+	struct utmpx	*utmp;
+#define UTMP_FILE	"/var/run/utmpx"
+#endif
 	static time_t	utmp_mtime;
 
-	if (stat(_PATH_UTMP, &s) != 0 || s.st_mtime == utmp_mtime)
+	if (stat(UTMP_FILE, &s) != 0 || s.st_mtime == utmp_mtime)
 		return;
+
+#ifdef _PATH_UTMP
 	if ((ut = fopen(_PATH_UTMP, "r")) != NULL)
 		{
 		n_users = 0;
@@ -226,14 +228,30 @@ gkrellm_sys_proc_read_users(void)
 				continue;
 			(void)snprintf(ttybuf, sizeof(ttybuf), "%s/%s",
 				       _PATH_DEV, utmp.ut_line);
-			/* corrupted record */
 			if (stat(ttybuf, &sb))
-				continue;
+				continue;	/* corrupted record */
 			++n_users;
 			}
 		(void)fclose(ut);
 		gkrellm_proc_assign_users(n_users);
 		}
+#else
+	setutxent();
+	n_users = 0;
+	while ((utmp = getutxent()) != NULL)
+		{
+		if (utmp->ut_type != USER_PROCESS)
+			continue;
+		(void)snprintf(ttybuf, sizeof(ttybuf), "%s/%s",
+			       _PATH_DEV, utmp->ut_line);
+		if (stat(ttybuf, &sb))
+			continue;		/* corrupted record */
+		++n_users;
+		}
+	endutxent();
+	gkrellm_proc_assign_users(n_users);
+#endif
+
 	utmp_mtime = s.st_mtime;
 	}
 
@@ -252,7 +270,7 @@ gkrellm_sys_disk_name_from_device(gint device_number, gint unit_number,
 	}
 
 gint
-gkrellm_sys_disk_order_from_name(gchar *name)
+gkrellm_sys_disk_order_from_name(const gchar *name)
 	{
 	return -1;	/* Append as added */
 	}
@@ -336,19 +354,13 @@ gkrellm_sys_inet_read_tcp_data(void)
 	void *so_begin, *so_end;
 	struct xtcpcb *xtp;
 	struct inpcb *inp;
-	struct xsocket *so;
-	const char *varname, *protoname;
+	const char *varname;
 	size_t len;
 	void *buf;
-	int vflag;
 	ActiveTCP	tcp;
 	gint		tcp_status;
 
 	varname = "net.inet.tcp.pcblist";
-	protoname = "tcp";
-
-	vflag = INP_IPV4 | INP_IPV6;
-
 	buf = NULL;
 	len = 0;
 
@@ -371,17 +383,24 @@ gkrellm_sys_inet_read_tcp_data(void)
 		if (xtp->xt_len != sizeof *xtp)
 			goto out;
 		inp = &xtp->xt_inp;
-		so = &xtp->xt_socket;
-		if ((inp->inp_vflag & vflag) == 0)
-			continue;
+#ifdef in6p_vflag
 		if (inp->inp_vflag & INP_IPV4) {
+#else
+		if (INP_ISIPV4(inp)) {
+#endif
 			tcp.remote_addr.s_addr = inp->inp_faddr.s_addr;
 			tcp.family = AF_INET;
+#ifdef in6p_vflag
 		} else if (inp->inp_vflag & INP_IPV6) {
+#else
+		} else if (INP_ISIPV6(inp)) {
+#endif
 			memcpy(&tcp.remote_addr6,
 			       &inp->in6p_faddr,
 			       sizeof(struct in6_addr));
-				tcp.family = AF_INET6;
+			tcp.family = AF_INET6;
+		} else {
+			continue;
 		}
 
 		tcp.remote_port = ntohs(inp->inp_fport);
@@ -458,7 +477,7 @@ swapmode(guint64 *retavail, guint64 *retfree)
 	*retfree = avail - used;
 
 	/* increase counter, no errors occurs */
-	warning++; 
+	warning++;
 
 	return  (int)(((double)used / (double)avail * 100.0) + 0.5);
 	}
@@ -482,10 +501,10 @@ get_bufspace(guint64 *bufspacep)
 		}
 
 	if (sysctl(oid_bufspace, oid_bufspace_len,
-		   &bufspace, &bufspace_len, 0, 0) < 0)
+		   &bufspace, &bufspace_len, NULL, 0) < 0)
 		return 0;
 	*bufspacep = bufspace;
-	return 1;	
+	return 1;
 	}
 
 struct mibtab {
@@ -532,7 +551,7 @@ gkrellm_sys_mem_read_data(void)
 	{
 	static gint	psize, pshift = 0;
 	static gint	first_time_done = 0;
-	guint64		total, used, x_used, free, shared, buffers, cached;
+	guint64		total, used, free, shared, buffers = 0, cached;
 	struct vmtotal	vmt;
 	size_t		length_vmt = sizeof(vmt);
 	static int	oid_vmt[] = { CTL_VM, VM_TOTAL };
@@ -540,15 +559,6 @@ gkrellm_sys_mem_read_data(void)
 	FILE		*f;
 	gchar		buf[160];
 
-#if 0
-	/* mem.c does a force_meminfo_update() before calling this */
-	/* Collecting meminfo data is expensive under FreeBSD, so
-	|  take extra precautions to minimize reading it.
-	*/
-	if (!GK.ten_second_tick && !force_meminfo_update())
-		return;
-#endif
-
 	if (pshift == 0)
 		{
 		for (psize = getpagesize(); psize > 1; psize >>= 1)
@@ -556,35 +566,29 @@ gkrellm_sys_mem_read_data(void)
 		}
 
 	shared = 0;
-
 	if (!first_time_done)
 		{
 		for (i = 0; mibs[i].name; ++i)
 			{
 			mibs[i].oid_len = sizeof(mibs[i].oid);
-			if (gk_sysctlnametomib(mibs[i].name,
-					       mibs[i].oid,
+			if (gk_sysctlnametomib(mibs[i].name, mibs[i].oid,
 					       &mibs[i].oid_len) < 0)
-			 	return;
+				return;
 			mibs[i].value_len = sizeof(mibs[i].value);
 			}
-		++first_time_done;
 		}
 	for (i = 0; mibs[i].name; ++i)
-		if (sysctl(mibs[i].oid, mibs[i].oid_len,
-			   &mibs[i].value,
-			   &mibs[i].value_len, 0, 0) < 0)
+		if (sysctl(mibs[i].oid, mibs[i].oid_len, &mibs[i].value,
+			   &mibs[i].value_len, NULL, 0) < 0)
 			return;
-	total = (mibs[MIB_V_PAGE_COUNT].value -
-		     mibs[MIB_V_WIRE_COUNT].value) << pshift;
-	x_used = (mibs[MIB_V_ACTIVE_COUNT].value +
-		      mibs[MIB_V_INACTIVE_COUNT].value) << pshift;
-	free = mibs[MIB_V_FREE_COUNT].value << pshift;
+	total = (guint64)(mibs[MIB_V_PAGE_COUNT].value) << pshift;
+	free = (guint64)(mibs[MIB_V_INACTIVE_COUNT].value +
+			 mibs[MIB_V_FREE_COUNT].value) << pshift;
 	if (sysctl(oid_vmt, 2, &vmt, &length_vmt, NULL, 0) == 0)
-		shared = vmt.t_rmshr << pshift;
+		shared = (guint64)vmt.t_rmshr << pshift;
 	get_bufspace(&buffers);
-	cached = mibs[MIB_V_CACHE_COUNT].value << pshift;
-	used = x_used - buffers - cached;
+	cached = (guint64)mibs[MIB_V_CACHE_COUNT].value << pshift;
+	used = total - free;
 	gkrellm_mem_assign_data(total, used, free, shared, buffers, cached);
 
 	swapin = mibs[MIB_V_SWAPPGSIN].value;
@@ -599,7 +603,7 @@ gkrellm_sys_mem_read_data(void)
 			{
 			if (strncmp(buf, "Swap:", 5) == 0)
 				{
-				sscanf(buf, "Swap: %llu %llu",
+				sscanf(buf, "Swap: %lu %lu",
 				       &swap_total, &swap_used);
 				break;
 				}
@@ -609,11 +613,11 @@ gkrellm_sys_mem_read_data(void)
 	}
 
 	if (first_time_done == 0)
-	{
-	swapmode(&swap_total, &swap_used);
-	swap_used = swap_total - swap_used;
-	first_time_done = 1;
-	}
+		{
+		first_time_done = 1;
+		swapmode(&swap_total, &swap_used);
+		swap_used = swap_total - swap_used;
+		}
 	}
 
 void
@@ -667,11 +671,13 @@ gkrellm_sys_battery_read_data(void)
 	size_t		size;
 	int		acpi_info[4];
 	int		i;
+#if defined(__i386__)
 	int		f, r;
 	struct apm_info	info;
+	gint		batt_num = 0;
+#endif
 	gboolean	available, on_line, charging;
 	gint		percent, time_left;
-	gint		batt_num = 0;
 
 	if (!first_time_done)
 		{
@@ -716,6 +722,7 @@ gkrellm_sys_battery_read_data(void)
 			return;
 		}
 
+#if defined(__i386__)
 	if ((f = open(APMDEV, O_RDONLY)) == -1)
 		return;
 	if ((r = ioctl(f, APMIO_GETINFO, &info)) == -1) {
@@ -773,6 +780,7 @@ gkrellm_sys_battery_read_data(void)
 #endif
 
 	close(f);
+#endif
 	}
 
 gboolean
@@ -800,7 +808,9 @@ gkrellm_sys_battery_init(void)
 /* ===================================================================== */
 /* Sensor monitor interface */
 
-#if defined(__i386__)
+#if defined(__i386__) || defined(__x86_64__)
+
+#include <sys/sensors.h>
 
 typedef struct
 	{
@@ -830,16 +840,13 @@ static VoltDefault	voltdefault0[] =
 #include <dirent.h>
 #include <osreldate.h>
 #include <machine/cpufunc.h>
-#if (__DragonFly_version < 200700)
-#include <machine/smb.h>
-#else
-#include <bus/smbus/smb.h>
-#endif
+#include <dev/smbus/smb/smb.h>
 
 /* Interface types */
 #define INTERFACE_IO		0
 #define INTERFACE_SMB		1
 #define INTERFACE_ACPI		2
+#define INTERFACE_CORETEMP	3
 
 /* Addresses to use for /dev/io */
 #define WBIO1			0x295
@@ -872,7 +879,9 @@ get_data(int iodev, u_char command, int interface, u_char *ret)
 		struct smbcmd cmd;
 
 		bzero(&cmd, sizeof(cmd));
-		cmd.data.byte_ptr = &byte;
+#if 0
+		cmd.data.byte_ptr = (char *)&byte;
+#endif
 		cmd.slave         = 0x5a;
 		cmd.cmd           = command;
 		if (ioctl(iodev, SMB_READB, (caddr_t)&cmd) == -1)
@@ -880,6 +889,7 @@ get_data(int iodev, u_char command, int interface, u_char *ret)
 			close(iodev);
 			return FALSE;
 			}
+		byte = (u_char)cmd.rdata.byte;
 		}
 	else
 		{
@@ -897,6 +907,8 @@ gkrellm_sys_sensors_get_temperature(gchar *path, gint id,
 
 	{
 	u_char byte;
+	int value;
+	size_t size;
 
 	if (interface == MBMON_INTERFACE)
 		{
@@ -906,15 +918,31 @@ gkrellm_sys_sensors_get_temperature(gchar *path, gint id,
 
 	if (interface == INTERFACE_ACPI)
 		{
-		int value;
-		size_t size = sizeof(value);
-
+		size = sizeof(value);
 		if (sysctlbyname(path, &value, &size, NULL, 0) < 0)
 			return FALSE;
 		if (temp)
-			*temp = (gfloat) TZ_KELVTOC(value);
+			*temp = (interface == INTERFACE_CORETEMP) ?
+				(gfloat) value : (gfloat) TZ_KELVTOC(value);
 		return TRUE;
 		}
+
+	else if (interface == INTERFACE_CORETEMP)
+		{
+		struct sensor sensor;
+		size_t	slen;
+		slen = sizeof(struct sensor);
+
+		size = sizeof(value);
+		if (sysctlbyname(path, &sensor, &slen, NULL, 0) < 0)
+			return FALSE;
+		if (sensor.type != SENSOR_TEMP)
+			return FALSE;
+		if (temp)
+			*temp = (float) ((sensor.value - 273150000) / 1000000.0);
+		return TRUE;
+		}
+
 	if (get_data(iodev, LM78_TEMP, interface, &byte))
 		{
 		if (temp)
@@ -968,6 +996,13 @@ gkrellm_sys_sensors_get_voltage(gchar *path, gint id,
 	return FALSE;
 	}
 
+gboolean
+gkrellm_sys_sensors_get_power(gchar *path, gint id,
+		gint iodev, gint interface, gfloat *power)
+	{
+	return FALSE;
+	}
+
 struct freebsd_sensor {
 	gint type;
 	gchar *id_name;
@@ -986,8 +1021,8 @@ gkrellm_sys_sensors_init(void)
 	{
 	gchar		mib_name[256], label[8];
 	gint		interface, id;
-	int		oid_acpi_temp[CTL_MAXNAME + 2];
-	size_t		oid_acpi_temp_len = sizeof(oid_acpi_temp);
+	int		oid[CTL_MAXNAME + 2];
+	size_t		oid_len;
 	GList		*list;
 	struct freebsd_sensor *sensor;
 
@@ -995,12 +1030,13 @@ gkrellm_sys_sensors_init(void)
 	*/
 	gkrellm_sys_sensors_mbmon_check(TRUE);
 
-	for (id = 0;;)
-	{
+	/* ACPI Thermal */
+	for (id = 0;; id++)
+		{
 		snprintf(mib_name, sizeof(mib_name),
 			 "hw.acpi.thermal.tz%d.temperature", id);
-		if (gk_sysctlnametomib(mib_name, oid_acpi_temp,
-				       &oid_acpi_temp_len) < 0)
+		oid_len = sizeof(oid);
+		if (gk_sysctlnametomib(mib_name, oid, &oid_len) < 0)
 			break;
 		interface = INTERFACE_ACPI;
 		if (!gkrellm_sys_sensors_get_temperature(mib_name, 0, 0,
@@ -1010,7 +1046,44 @@ gkrellm_sys_sensors_init(void)
 		gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE, NULL,
 					   mib_name, 0, 0,
 					   interface, 1.0, 0.0, NULL, label);
-	}
+		}
+
+	/* Coretemp cpu */
+	for (id = 0;; id++)
+		{
+		snprintf(mib_name, sizeof(mib_name),
+			 "hw.sensors.cpu%d.temp0", id);
+		oid_len = sizeof(oid);
+		if (gk_sysctlnametomib(mib_name, oid, &oid_len) < 0)
+			break;
+		interface = INTERFACE_CORETEMP;
+		if (!gkrellm_sys_sensors_get_temperature(mib_name, 0, 0,
+							 interface, NULL))
+			continue;
+		snprintf(label, sizeof(label), "cpu%d", id);
+		gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE, NULL,
+					   mib_name, 0, 0,
+					   interface, 1.0, 0.0, NULL, label);
+		}
+
+	/* Coretemp node */
+	for (id = 0;; id++)
+		{
+		snprintf(mib_name, sizeof(mib_name),
+			 "hw.sensors.cpu_node%d.temp0", id);
+		oid_len = sizeof(oid);
+		if (gk_sysctlnametomib(mib_name, oid, &oid_len) < 0)
+			break;
+		interface = INTERFACE_CORETEMP;
+		if (!gkrellm_sys_sensors_get_temperature(mib_name, 0, 0,
+							 interface, NULL))
+			continue;
+		snprintf(label, sizeof(label), "node%d", id);
+		gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE, NULL,
+					   mib_name, 0, 0,
+					   interface, 1.0, 0.0, NULL, label);
+		}
+
 
 	if (freebsd_sensor_list)
 		{
@@ -1044,13 +1117,7 @@ sensors_add_sensor(gint type, gchar *id_name, gint id, gint iodev, gint inter,
 	sensor->factor = factor;
 	sensor->offset = offset;
 	sensor->default_label = default_label ? g_strdup(default_label) : NULL;
-	if (g_list_append(freebsd_sensor_list, sensor) == NULL) {
-		g_free(sensor->id_name);
-		if (sensor->default_label)
-			g_free(sensor->default_label);
-		g_free(sensor);
-		return FALSE;
-	}
+	freebsd_sensor_list = g_list_append(freebsd_sensor_list, sensor);
 	return TRUE;
 }
 
@@ -1078,7 +1145,7 @@ scan_for_sensors(void)
 						chip_dir, dentry->d_name);
 			if ((iodev = open(temp_file, O_RDWR)) == -1)
 				continue;
-			sprintf(id_name, "%s%3s", "temp", dentry->d_name + 3);
+			snprintf(id_name, sizeof(id_name), "%s%3s", "temp", dentry->d_name + 3);
 			interface = INTERFACE_SMB;
 			if (!gkrellm_sys_sensors_get_temperature(NULL, 0, iodev,
 					interface, NULL))
@@ -1122,7 +1189,7 @@ scan_for_sensors(void)
 				if (!gkrellm_sys_sensors_get_fan(NULL, id, iodev,
 						interface, NULL))
 					continue;
-				sprintf(id_name, "%s%d", "fan", id);
+				snprintf(id_name, sizeof(id_name), "%s%d", "fan", id);
 				sensors_add_sensor(SENSOR_FAN, id_name, id,
 						iodev, interface,
 						1.0 / (gfloat) fandiv[id], 0.0,
@@ -1134,7 +1201,7 @@ scan_for_sensors(void)
 			if (!gkrellm_sys_sensors_get_voltage(NULL, id, iodev,
 					interface, NULL))
 				continue;
-			sprintf(id_name, "%s%d", "in", id);
+			snprintf(id_name, sizeof(id_name), "%s%d", "in", id);
 			sensors_add_sensor(SENSOR_VOLTAGE, id_name, id,
 					iodev, interface,
 					voltdefault0[id].factor, 0.0,
@@ -1167,6 +1234,13 @@ gkrellm_sys_sensors_get_voltage(gchar *path, gint id,
 	return FALSE;
 	}
 
+gboolean
+gkrellm_sys_sensors_get_power(gchar *path, gint id,
+		gint iodev, gint interface, gfloat *power)
+	{
+	return FALSE;
+	}
+
 gboolean
 gkrellm_sys_sensors_init(void)
 	{
