@@ -33,9 +33,17 @@
 |  as that of the covered work.
 */
 
+#include <errno.h>
+#include <fcntl.h>
+#include <glib.h>
 #include <kstat.h>
 #include <kvm.h>
-#include <fcntl.h>
+#include <libdevinfo.h>
+#include <stdio.h>
+#include <sys/dkio.h>
+#include <sys/sysinfo.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 kstat_ctl_t *kc;
 kvm_t *kd = NULL;
@@ -45,7 +53,127 @@ struct nlist nl[] = {
     { 0 }
 };
 
-extern void solaris_list_harddisks(void);
+
+/*
+ * An sd instance could be a cdrom or a harddrive. You can't simply tell,
+ * from contents of kstat, which type of device an sd device is
+ * (well, maybe you could, but at least i can't.)
+ * It, however, doesn't make much sense to count cdrom read/write as
+ * "Disk" activity. So I'd like to exclude removable media's from
+ * monitoring target. In order to do this, I try to open a physical
+ * device of a corresponding sd instance. If it's succeeded, I assume
+ * it's a hard drive. If I get ENXIO or EBUSY, I'll guess it's CDROM.
+ * If you come up with a better (simpler or safer) way to tell it's
+ * a removable media or a hard drive, please drop me an e-mail at
+ * Daisuke Yabuki <dxy@acm.org>.
+ * I don't know any other driver which handle both hard drive and
+ * removable media, by the way. I hope it wouldn't do any harm on
+ * other type of devices, i.e. ssd, or IDE drivers.
+ */
+static int
+check_media_type(di_node_t root_node, const kstat_t *ksp) {
+    di_node_t node = di_drv_first_node(ksp->ks_module, root_node);
+    while (node != DI_NODE_NIL) {
+        if (di_instance(node) != ksp->ks_instance) {
+            node = di_drv_next_node(node);
+            continue;
+        }
+
+        char *phys_path = di_devfs_path(node);
+        if (phys_path == NULL) {
+            perror("di_devfs_path");
+            return -1;
+        }
+
+        char devices_path[256]; /* or OBP_MAXPATHLEN? */
+        if (sprintf(devices_path, "/devices%s:c,raw", phys_path) <= 0) {
+            di_devfs_path_free(phys_path);
+            return -1;
+        }
+        di_devfs_path_free(phys_path);
+
+        const int fd = open(devices_path, O_RDONLY);
+        if (fd == -1) {
+            const int err = errno;
+            if (err == ENXIO || err == EBUSY) {
+                close(fd);
+                return 0; /* guess it's removable media */
+            } else {
+                gkrellm_debug(DEBUG_SYSDEP, "Could not check media type for device '%s': %s(%d)\n",
+                    devices_path, g_strerror(err), err);
+                close(fd);
+                return -1; /* EACCESS (unless setgid sys) or suchlike */
+            }
+        }
+
+        int dkRemovable;
+        if (ioctl(fd, DKIOCREMOVABLE, &dkRemovable) < 0) {
+            close(fd);
+            return -1;
+        }
+        close(fd);
+
+        return (dkRemovable == 0) ? 1 : 0;
+    }
+
+    return -1; /* shouldn't be reached */
+}
+
+
+static gboolean
+kstat_is_disk(const kstat_t *ksp) {
+    if (ksp->ks_type != KSTAT_TYPE_IO)
+        return FALSE;
+    if (strncmp(ksp->ks_class, "disk", 4) != 0)
+        return FALSE; /* excluding nfs etc. */
+    if (strcmp(ksp->ks_module, "fd") == 0)
+        return FALSE; /* excluding fd */
+    return TRUE;
+}
+
+
+static GList *disk_name_list;
+
+/*
+ * creating a preliminary list of drives, which should be a complete
+ * list of drives available on the system. the list is not supposed to
+ * contain nfs, fd, cdrom, cdrw etc.
+ */
+static void
+init_disk_name_list(void) {
+    gkrellm_debug(DEBUG_SYSDEP, "Creating list of non-removable disks\n");
+
+    extern kstat_ctl_t *kc;
+    if (kstat_chain_update(kc) == -1) {
+        perror("kstat_chain_update");
+        return;
+    }
+
+    // device tree info for checking for removable media
+    di_node_t root_node = di_init("/", DINFOCPYALL);
+    if (root_node == DI_NODE_NIL) {
+        perror("di_init");
+        return;
+    }
+
+    for (kstat_t *ksp = kc->kc_chain; ksp; ksp = ksp->ks_next) {
+        // skip non-disks and removable disks
+        // check_media_type() may require elevated access rights!
+        if (!kstat_is_disk(ksp) || check_media_type(root_node, ksp) == 0)
+            continue;
+        gkrellm_debug(DEBUG_SYSDEP, "Found disk: %s\n", ksp->ks_name);
+        disk_name_list = g_list_append(disk_name_list, g_strdup(ksp->ks_name));
+    }
+
+    di_fini(root_node);
+}
+
+static void
+cleanup_disk_name_list(void) {
+    gkrellm_debug(DEBUG_SYSDEP, "Cleaning up list of non-removable disks\n");
+
+    g_list_free_full(disk_name_list, g_free);
+}
 
 
 void
@@ -65,7 +193,10 @@ gkrellm_sys_main_init(void)
      * from kernel variable called mpid. Even if kvm_open() fails,
      * we proceed without it.
      */
-    if ((kd = kvm_open(NULL, NULL, NULL, O_RDONLY, NULL)) != NULL) {
+    kd = kvm_open(NULL, NULL, NULL, O_RDONLY, NULL);
+    if (kd == NULL) {
+        gkrellm_debug(DEBUG_SYSDEP, "Could not open kvm, no process fork statistics.\n");
+    } else {
         kvm_nlist(kd, nl);
     }
 
@@ -73,7 +204,7 @@ gkrellm_sys_main_init(void)
      * a function called by the following requires sys gid privilege.
      * the following function should be performed here just for that reason.
      */
-    solaris_list_harddisks();
+    init_disk_name_list();
 
     if (setgid(getgid()) != 0) {
         perror("Failed to drop setgid privilege");
@@ -84,6 +215,10 @@ gkrellm_sys_main_init(void)
 void
 gkrellm_sys_main_cleanup(void)
 {
+    if (kd != NULL) {
+        kvm_close(kd);
+    }
+    cleanup_disk_name_list();
 }
 
 
@@ -233,14 +368,6 @@ gkrellm_sys_proc_init(void)
 /* ===================================================================== */
 /* Disk monitor interface */
 
-#include <sys/types.h>
-#include <sys/sysinfo.h>
-#include <unistd.h>
-#include <kstat.h>
-#include <libdevinfo.h>
-#include <errno.h>
-#include <sys/dkio.h>
-
 #define UNIT_SHIFT 3
 
 #define NAME2MAJOR 0
@@ -251,16 +378,6 @@ typedef struct {
     gchar name[32];
 } name_to_major_t;
 
-static gint check_media_type(kstat_t *);
-static gint isharddisk(kstat_t *);
-void solaris_list_harddisks(void);                   /* called from main.c */
-
-typedef struct {
-    char name[8];
-} probed_harddisk;
-
-GList *hard_disk_list;
-
 
 gchar *
 gkrellm_sys_disk_name_from_device(gint device_number, gint unit_number,
@@ -278,39 +395,29 @@ gkrellm_sys_disk_order_from_name(const gchar *name)
 void
 gkrellm_sys_disk_read_data(void)
 {
-    probed_harddisk *drive;
-    GList *list;
-
     extern kstat_ctl_t *kc;
-    kstat_t *ksp;
-    kstat_io_t kios;
-
     if (kstat_chain_update(kc) == -1) {
         perror("kstat_chain_update");
         return;
     }
-    for (ksp = kc->kc_chain; ksp; ksp = ksp->ks_next) {
-        if (ksp->ks_type != KSTAT_TYPE_IO ||
-            strcmp(ksp->ks_class, "disk")) {
+
+    for (kstat_t *ksp = kc->kc_chain; ksp; ksp = ksp->ks_next) {
+        if (!kstat_is_disk(ksp))
             continue;
-        }
-        for (list = hard_disk_list; list; list = list->next) {
-                drive = (probed_harddisk *)list->data;
 
-                if (strcmp(drive->name, ksp->ks_name))
-                    continue;
+        for (GList *list = disk_name_list; list; list = list->next) {
+            const char *drive_name = (const char *)list->data;
+            if (strcmp(drive_name, ksp->ks_name) != 0)
+                continue;
 
-                memset((void *)&kios, 0, sizeof(kstat_io_t));
+            kstat_io_t kios;
+            memset((void *)&kios, 0, sizeof(kstat_io_t));
+            if (kstat_read(kc, ksp, &kios) == -1) {
+                perror("kstat_read");
+                return;
+            }
 
-                if (kstat_read(kc, ksp, &kios) == -1) {
-                    perror("kstat_read");
-                    return;
-                }
-
-            gkrellm_disk_assign_data_by_name(drive->name,
-                            kios.nread, kios.nwritten, FALSE);
-            /* We don't need to keep searching the list
-             * for a matching hard drive name if we've reached here */
+            gkrellm_disk_assign_data_by_name(ksp->ks_name, kios.nread, kios.nwritten, FALSE);
             break;
         }
     }
@@ -323,131 +430,6 @@ gkrellm_sys_disk_init(void)
 }
 
 
-/*
- * An sd instance could be a cdrom or a harddrive. You can't simply tell,
- * from contents of kstat, which type of device an sd device is
- * (well, maybe you could, but at least i can't.)
- * It, however, doesn't make much sense to count cdrom read/write as
- * "Disk" activity. So I'd like to exclude removable media's from
- * monitoring target. In order to do this, I try to open a physical
- * device of a corresponding sd instance. If it's succeeded, I assume
- * it's a hard drive. If I get ENXIO or EBUSY, I'll guess it's CDROM.
- * If you come up with a better (simpler or safer) way to tell it's
- * a removable media or a hard drive, please drop me an e-mail at
- * Daisuke Yabuki <dxy@acm.org>.
- * I don't know any other driver which handle both hard drive and
- * removable media, by the way. I hope it wouldn't do any harm on
- * other type of devices, i.e. ssd, or IDE drivers.
- */
-static gint
-check_media_type(kstat_t *ksp) {
-    gint fd;
-    char *phys_path, devices_path[256]; /* or OBP_MAXPATHLEN? */
-    di_node_t node;
-    static di_node_t root_node = NULL;
-#if 0
-    /* Not supported on Solaris 7 */
-    struct dk_minfo dk;
-#else
-    int dkRemovable;
-#endif
-
-    if (root_node == NULL) {
-        if ((root_node = di_init("/", DINFOCPYALL)) == DI_NODE_NIL) {
-                perror("di_init");
-                return -1;
-        }
-    }
-
-    node = di_drv_first_node(ksp->ks_module, root_node);
-    while (node != DI_NODE_NIL) {
-        if (di_instance(node) != ksp->ks_instance) {
-            node = di_drv_next_node(node);
-            continue;
-        }
-        if ((phys_path = di_devfs_path(node)) == NULL) {
-            perror("di_devfs_path");
-            return -1;
-        }
-        if (sprintf(devices_path, "/devices%s:c,raw", phys_path) <= 0) {
-            di_devfs_path_free(phys_path);
-            return -1;
-        }
-        if ((fd = open(devices_path, O_RDONLY)) == -1) {
-            if (errno == ENXIO || errno == EBUSY) {
-                close(fd);
-                di_devfs_path_free(phys_path);
-                return 0; /* guess it's removable media */
-            } else {
-#ifdef DEBUG
-                g_message("opening %s\n", devices_path);
-                g_message("unexpected errno: %d\n", errno);
-                g_message("disabled auto-detection/exclusion of removable media\n");
-#endif
-                close(fd);
-                di_devfs_path_free(phys_path);
-                return -1; /* EACCESS (unless setgid sys) or suchlike */
-            }
-        }
-        if (ioctl(fd, DKIOCREMOVABLE, &dkRemovable) < 0)
-        {
-                close(fd);
-                di_devfs_path_free(phys_path);
-                return -1;
-        }
-
-        if (!dkRemovable)
-        {
-           close(fd);
-           di_devfs_path_free(phys_path);
-           return 1;
-        }
-
-        return 0;
-    }
-
-    return -1; /* shouldn't be reached */
-}
-
-static gint
-isharddisk(kstat_t *ksp) {
-    if (ksp->ks_type != KSTAT_TYPE_IO)
-        return 0;
-    if (strncmp(ksp->ks_class, "disk", 4))
-        return 0; /* excluding nfs etc. */
-    if (!strcmp(ksp->ks_module, "fd"))
-        return 0; /* excluding fd */
-    if (check_media_type(ksp) == 0)
-        return 0; /* guess it's removable media (e.g. CD-ROM, CD-R/W etc) */
-    return 1;
-}
-
-/*
- * creating a preliminary list of drives, which should be a complete
- * list of drives available on the system. the list is not supposed to
- * contain nfs, fd, cdrom, cdrw etc.
- */
-void
-solaris_list_harddisks(void) {
-    extern kstat_ctl_t *kc;
-    kstat_t *ksp;
-    probed_harddisk *drive;
-
-    if (kstat_chain_update(kc) == -1) {
-        perror("kstat_chain_update");
-        return;
-    }
-
-    for (ksp = kc->kc_chain; ksp; ksp = ksp->ks_next) {
-        if(isharddisk(ksp)) {
-             drive = g_new0(probed_harddisk, 1);
-             hard_disk_list = g_list_append(hard_disk_list, drive);
-             strcpy(drive->name, ksp->ks_name);
-        }
-    }
-}
-
-
 /* ===================================================================== */
 /* Inet monitor interface */
 
@@ -599,6 +581,19 @@ gkrellm_sys_inet_init(void)
  * If you need this functionality, feel free to modify my code.
  */
 
+
+static gboolean
+kstat_is_net(const kstat_t *ksp) {
+    if (ksp->ks_type != KSTAT_TYPE_NAMED)
+        return FALSE;
+    if (strcmp(ksp->ks_class, "net"))
+        return FALSE;
+    if (strcmp(ksp->ks_module, "link"))
+        return FALSE;
+    return TRUE;
+}
+
+
 void
 gkrellm_sys_net_read_data(void)
 {
@@ -613,23 +608,24 @@ gkrellm_sys_net_read_data(void)
     }
 
     for (ksp = kc->kc_chain; ksp; ksp = ksp->ks_next) {
-        if (!strcmp(ksp->ks_class, "net") && !strcmp(ksp->ks_name, "link")) {
-            kstat_read(kc, ksp, NULL);
+        if (!kstat_is_net(ksp))
+            continue;
 
-            knp = kstat_data_lookup(ksp, "rbytes");
-            if (knp == NULL)
-                continue;
+        kstat_read(kc, ksp, NULL);
 
-            rx = knp->value.ui32;
+        knp = kstat_data_lookup(ksp, "rbytes");
+        if (knp == NULL)
+            continue;
 
-            knp = kstat_data_lookup(ksp, "obytes");
-            if (knp == NULL)
-                continue;
+        rx = knp->value.ui32;
 
-            tx = knp->value.ui32;
+        knp = kstat_data_lookup(ksp, "obytes");
+        if (knp == NULL)
+            continue;
 
-            gkrellm_net_assign_data(ksp->ks_name, rx, tx);
-        }
+        tx = knp->value.ui32;
+
+        gkrellm_net_assign_data(ksp->ks_name, rx, tx);
     }
 
 }
