@@ -2,7 +2,7 @@
 |  Copyright (C) 1999-2021 Bill Wilson
 |                2007-2024 Stefan Gehn
 |
-|  Authors:  Bill Wilson    billw@gkrellm.net
+|  Authors:  Bill Wilson
 |            Stefan Gehn    stefan+gkrellm@srcbox.net
 |  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
@@ -136,7 +136,7 @@ gkrellm_winop_place_gkrellm(gchar *geom)
 	if (   newX >= 0 && newX < _GK.w_display - 10
 	    && newY >= 0 && newY < _GK.h_display - 25)
 		{
-		gdk_window_move(gkrellm_get_top_window()->window, newX, newY);
+		gdk_window_move(gtk_widget_get_window(gkrellm_get_top_window()), newX, newY);
 		_GK.y_position = newY;
 		_GK.x_position = newX;
 		}
@@ -163,7 +163,7 @@ gkrellm_winop_update_struts(void)
 gboolean
 gkrellm_winop_draw_rootpixmap_onto_transparent_chart(GkrellmChart *p)
 	{
-	if (!p->transparency || !p->drawing_area || !p->drawing_area->window || !trans_gc)
+	if (!p->transparency || !p->drawing_area || !trans_gc)
 		return FALSE;
 
 	// Fill the panel with transparency color
@@ -185,7 +185,7 @@ gkrellm_winop_draw_rootpixmap_onto_transparent_chart(GkrellmChart *p)
 gboolean
 gkrellm_winop_draw_rootpixmap_onto_transparent_panel(GkrellmPanel *p)
 	{
-	if (!p->transparency || !p->drawing_area || !p->drawing_area->window || !trans_gc)
+	if (!p->transparency || !p->drawing_area || !trans_gc)
 		return FALSE;
 
 	gdk_gc_set_fill(trans_gc, GDK_SOLID);
@@ -257,7 +257,8 @@ gkrellm_winop_apply_rootpixmap_transparency(void)
 	GkrellmPanel	*p;
 	HWND			w;
 
-	w = GDK_WINDOW_HWND(gkrellm_get_top_window()->window);
+	GdkWindow *top_window = gtk_widget_get_window(gkrellm_get_top_window());
+	w = GDK_WINDOW_HWND(top_window);
 	if (!_GK.any_transparency && isTransparent)
 		{	// make opaque
 		SetWindowLong(w, GWL_EXSTYLE, GetWindowLong(w, GWL_EXSTYLE) & ~WS_EX_LAYERED);
@@ -270,7 +271,7 @@ gkrellm_winop_apply_rootpixmap_transparency(void)
 			{
 			GdkColormap *cm = gtk_widget_get_colormap(gkrellm_get_top_window());
 
-			trans_gc = gdk_gc_new(gkrellm_get_top_window()->window);
+			trans_gc = gdk_gc_new(top_window);
 			if (trans_gc == NULL)
 				{
 				g_warning("Could not create trans_gc!\n");
